from pollination_dsl.alias import OutputAlias
from queenbee.io.common import IOAliasHandler


"""Annual energy use recipe output.

The result is a JSON with various end uses of energy.
"""
parse_eui_results = [
    OutputAlias.any(
        name='eui',
        description='Energy Use intensity, including total and for each end use.',
        platform=['grasshopper'],
        handler=[
            IOAliasHandler(
                language='python',
                module='pollination_handlers.outputs.eui',
                function='eui_json_from_path'
            )
        ]
    )
]



from pollination_dsl.alias import OutputAlias
from queenbee.io.common import IOAliasHandler


"""Alias for Thermal Comfort Percent (TCP)"""
tcp_output = [
    OutputAlias.any(
        name='TCP',
        description='Lists of values between 0 and 100 for the Thermal Comfort Percent '
        '(TCP). These can be plugged into the "LB Spatial Heatmap" component along '
        'with meshes of the sensor grids to visualize spatial thermal comfort. '
        'TCP is the percentage of occupied time where thermal conditions are '
        'acceptable/comfortable. Occupied hours are determined from the '
        'occupancy schedules of each room (any time where the occupancy '
        'schedule is >= 0.1 will be considered occupied). Outdoor sensors '
        'are considered occupied at all times. More custom TCP studies can '
        'be done by post-processing the condition results.',
        platform=['grasshopper'],
        handler=[
            IOAliasHandler(
                language='python',
                module='pollination_handlers.outputs.comfort',
                function='read_comfort_percent_from_folder'
            )
        ]
    ),
    # Rhino alias
    OutputAlias.linked(
        name='TCP',
        platform=['rhino'],
        handler=[
            # Preload results 
            IOAliasHandler(
                language='python',
                module='pollination_handlers.outputs.comfort',
                function='read_comfort_percent_from_folder'
            ),
            # load preloaded outputs to Rhino with following method
            IOAliasHandler(
                language='csharp', module='Pollination.RhinoHandlers',
                function='LoadMeshBasedResultsToRhino'
            )
        ]
    )
]


"""Alias for Heat Sensation Percent (HSP)"""
hsp_output = [
    OutputAlias.any(
        name='HSP',
        description='Lists of values between 0 and 100 for the Heat Sensation Percent '
        '(HSP). These can be plugged into the "LB Spatial Heatmap" component along with '
        'meshes of the sensor grids to visualize uncomfortably hot locations. '
        'HSP is the percentage of occupied time where thermal conditions are '
        'hotter than what is considered acceptable/comfortable. Occupied hours '
        'are determined from the occupancy schedules of each room (any time '
        'where the occupancy schedule is >= 0.1 will be considered occupied). '
        'Outdoor sensors are considered occupied at all times. More custom HSP '
        'studies can be done by post-processing the condition results.',
        platform=['grasshopper'],
        handler=[
            IOAliasHandler(
                language='python',
                module='pollination_handlers.outputs.comfort',
                function='read_comfort_percent_from_folder'
            )
        ]
    ),
    # Rhino alias
    OutputAlias.linked(
        name='HSP',
        platform=['rhino'],
        handler=[
            # Preload results 
            IOAliasHandler(
                language='python',
                module='pollination_handlers.outputs.comfort',
                function='read_comfort_percent_from_folder'
            ),
            # load preloaded outputs to Rhino with following method
            IOAliasHandler(
                language='csharp', module='Pollination.RhinoHandlers',
                function='LoadMeshBasedResultsToRhino'
            )
        ]
    )
]


"""Alias for Cold Sensation Percent (CSP)."""
csp_output = [
    OutputAlias.any(
        name='CSP',
        description='Lists of values between 0 and 100 for the Cold Sensation Percent '
        '(CSP). These can be plugged into the "LB Spatial Heatmap" component along with '
        'meshes of the sensor grids to visualize uncomfortably cold locations. '
        'CSP is the percentage of occupied time where thermal conditions are '
        'colder than what is considered acceptable/comfortable. Occupied hours '
        'are determined from the occupancy schedules of each room (any time '
        'where the occupancy schedule is >= 0.1 will be considered occupied). '
        'Outdoor sensors are considered occupied at all times. More custom CSP '
        'studies can be done by post-processing the condition results.',
        platform=['grasshopper'],
        handler=[
            IOAliasHandler(
                language='python',
                module='pollination_handlers.outputs.comfort',
                function='read_comfort_percent_from_folder'
            )
        ]
    ),
    # Rhino alias
    OutputAlias.linked(
        name='CSP',
        platform=['rhino'],
        handler=[
            # Preload results 
            IOAliasHandler(
                language='python',
                module='pollination_handlers.outputs.comfort',
                function='read_comfort_percent_from_folder'
            ),
            # load preloaded outputs to Rhino with following method
            IOAliasHandler(
                language='csharp', module='Pollination.RhinoHandlers',
                function='LoadMeshBasedResultsToRhino'
            )
        ]
    )
]


"""Alias for thermal condition output."""
thermal_condition_output = [
    OutputAlias.any(
        name='condition',
        description='A folder containing CSV maps of comfort conditions for each '
        'sensor grid at each time step of the analysis. This can be connected to the '
        '"HB Read Thermal Matrix" component to parse detailed results into '
        'Grasshopper. -1 indicates unacceptably cold conditions. +1 indicates '
        'unacceptably hot conditions. 0 indicates neutral (comfortable) conditions.',
        platform=['grasshopper']
    )
]


"""Alias for operative temperature output."""
operative_temp_output = [
    OutputAlias.any(
        name='op_temp',
        description='A folder containing CSV maps of Operative Temperature for each '
        'sensor grid at each time step of the analysis. This can be connected to the '
        '"HB Read Thermal Matrix" component to parse detailed results into Grasshopper. '
        'Values are in Celsius.',
        platform=['grasshopper']
    )
]


"""Alias for degrees from neutral temperature output."""
degrees_neutral_output = [
    OutputAlias.any(
        name='deg_neut',
        description='A folder containing CSV maps of the degrees Celsius from the '
        'adaptive comfort neutral temperature for each sensor grid at each time step '
        'of the analysis. This can be connected to the "HB Read Thermal Matrix" '
        'component to parse detailed results into Grasshopper. This can be '
        'used to understand not just whether conditions are acceptable but '
        'how uncomfortably hot or cold they are.',
        platform=['grasshopper']
    )
]


"""Alias for operative temperature or SET output."""
operative_or_set_output = [
    OutputAlias.any(
        name='temperature',
        description='A folder containing CSV maps of Operative Temperature for each '
        'sensor grid at each time step of the analysis. Alternatively, if the '
        'write_set_map_ option is used, the CSV maps here will contain '
        'Standard Effective Temperature (SET). This can be connected to the '
        '"HB Read Thermal Matrix" component to parse detailed results into '
        'Grasshopper. Values are in Celsius.',
        platform=['grasshopper']
    )
]


"""Alias for Predicted Mean Vote output."""
pmv_output = [
    OutputAlias.any(
        name='pmv',
        description='A folder containing CSV maps of the Predicted Mean Vote (PMV) '
        'for each sensor grid at each time step of the analysis. This can be connected '
        'to the "HB Read Thermal Matrix" component to parse detailed results '
        'into Grasshopper. This can be used to understand not just whether '
        'conditions are acceptable but how uncomfortably hot or cold they are.',
        platform=['grasshopper']
    )
]


"""Alias for Universal Thermal Climate Index output."""
utci_output = [
    OutputAlias.any(
        name='utci',
        description='A folder containing CSV maps of Universal Thermal Climate Index '
        '(UTCI) temperatures for each sensor grid at each time step of the analysis. '
        'This can be connected to the "HB Read Thermal Matrix" component to '
        'parse detailed results into Grasshopper. Values are in Celsius.',
        platform=['grasshopper']
    )
]


"""Alias for UTCI Categories output."""
utci_category_output = [
    OutputAlias.any(
        name='category',
        description='A folder containing CSV maps of the heat/cold stress categories '
        'for each sensor grid at each time step of the analysis. This can be connected '
        'to the "HB Read Thermal Matrix" component to parse detailed results '
        'into Grasshopper. This can be used to understand not just whether '
        'conditions are acceptable but how uncomfortably hot or cold they '
        'are. Values indicate the following. '
        '-5 = extreme cold stress. '
        '-4 = very strong cold stress. '
        '-3 = strong cold stress. '
        '-2 = moderate cold stress. '
        '-1 = slight cold stress. '
        ' 0 = no thermal stress. '
        '+1 = slight heat stress. '
        '+2 = moderate heat stress. '
        '+3 = strong heat stress. '
        '+4 = very strong heat stress. '
        '+5 = extreme heat stress',
        platform=['grasshopper']
    )
]



from pollination_dsl.alias import InputAlias
from queenbee.io.common import IOAliasHandler


"""Alias for text that filters the simulated radiance grids."""
grid_filter_input = [
    InputAlias.str(
        name='grid_filter',
        description='Text for a grid identifer or a pattern to filter the sensor grids '
        'of the model that are simulated. For instance, first_floor_* will simulate '
        'only the sensor grids that have an identifier that starts with '
        'first_floor_. By default, all grids in the model will be simulated.',
        default='*',
        platform=['grasshopper']
    )
]


"""Alias for inputs that split sensor grids for parallel execution."""
sensor_count_input = [
    InputAlias.int(
        name='sensor_count',
        description='Positive integer for the number of sensor grid points per '
        'parallel execution. Lower numbers will result in sensor grids being '
        'split into more pieces and, since each grid piece is run by a separate worker, '
        'this can mean a faster simulation on machines with several CPUs. However ,'
        'If the number is too low, the overhad of splitting the grid will not be worth '
        'the time gained through parallelization. (Default: 200).',
        default=200,
        platform=['grasshopper']
    )
]



from pollination_dsl.alias import InputAlias
from queenbee.io.common import IOAliasHandler


"""Alias for thermal map air speeds."""
air_speed_input = [
    InputAlias.any(
        name='air_speed',
        description='A single number for air speed in m/s or an hourly data collection '
        'of air speeds that align with the input run_period. This will be '
        'used for all indoor comfort evaluation. Note that the EPW wind speed '
        'will be used for any outdoor sensors. (Default: 0.1).',
        default='0.1',
        platform=['grasshopper'],
        handler=[
            IOAliasHandler(
                language='python',
                module='pollination_handlers.inputs.data',
                function='value_or_data_to_str'
            )
        ]
    )
]


"""Alias for thermal map wind speeds."""
wind_speed_input = [
    InputAlias.any(
        name='wind_speed',
        description='A single number for meteorological wind speed in m/s or an hourly '
        'data collection of wind speeds that align with the input run period. '
        'This will be used for all indoor comfort evaluation. Note that the '
        'EPW wind speed will be used for any outdoor sensors. (Default: 0.5).',
        default='0.5',
        platform=['grasshopper'],
        handler=[
            IOAliasHandler(
                language='python',
                module='pollination_handlers.inputs.data',
                function='value_or_data_to_str'
            )
        ]
    )
]


"""Alias for thermal map metabolic rates."""
met_rate_input = [
    InputAlias.any(
        name='met_rate',
        description='A single number for metabolic rate in met or an hourly data '
        'collection of met rates that align with the run period. (Default: 1.1, for '
        'seated, typing).',
        default='1.1',
        platform=['grasshopper'],
        handler=[
            IOAliasHandler(
                language='python',
                module='pollination_handlers.inputs.data',
                function='value_or_data_to_str'
            )
        ]
    )
]


"""Alias for thermal map clothing levels."""
clo_value_input = [
    InputAlias.any(
        name='clo_value',
        description='A single number for clothing level in clo or an hourly data '
        'collection of clothing levels that align with the run period. (Default: 0.7, '
        'for pants and a long sleeve shirt).',
        default='0.7',
        platform=['grasshopper'],
        handler=[
            IOAliasHandler(
                language='python',
                module='pollination_handlers.inputs.data',
                function='value_or_data_to_str'
            )
        ]
    )
]


"""Alias for PMV comfort parameters."""
pmv_comfort_par_input = [
    InputAlias.str(
        name='comfort_par',
        description='Optional comfort parameters from the "LB PMV Comfort Parameters" '
        'component to specify the criteria under which conditions are '
        'considered acceptable/comfortable. The default will assume a '
        'PPD threshold of 10 percent and no absolute humidity constraints.',
        default='--ppd-threshold 10',
        platform=['grasshopper']
    )
]


"""Alias for Adaptive comfort parameters."""
adaptive_comfort_par_input = [
    InputAlias.str(
        name='comfort_par',
        description='Optional comfort parameters from the "LB Adaptive Comfort '
        'Parameters" component to specify the criteria under which conditions are '
        'considered acceptable/comfortable. The default will use ASHRAE-55 '
        'adaptive comfort criteria.',
        default='--standard ASHRAE-55',
        platform=['grasshopper']
    )
]


"""Alias for UTCI comfort parameters."""
utci_comfort_par_input = [
    InputAlias.str(
        name='comfort_par',
        description='UTCIParameter string to customize the assumptions of '
        'the UTCI comfort model.',
        default='--cold 9 --heat 26',
        platform=['grasshopper']
    )
]


"""Alias for indoor SolarCal parameters."""
solar_body_par_indoor_input = [
    InputAlias.str(
        name='solar_body_par',
        description='Optional solar body parameters from the "LB Solar Body Parameters" '
        'object to specify the properties of the human geometry assumed in the '
        'shortwave MRT calculation. The default assumes average skin/clothing '
        'absorptivity and a human subject always has their back to the sun '
        'at a 45-degree angle (SHARP = 135).',
        default='--posture seated --sharp 135 --absorptivity 0.7 --emissivity 0.95',
        platform=['grasshopper']
    )
]


"""Alias for outdoor SolarCal parameters."""
solar_body_par_outdoor_input = [
    InputAlias.str(
        name='solar_body_par',
        description='Optional solar body parameters from the "LB Solar Body Parameters" '
        'object to specify the properties of the human geometry assumed in the '
        'shortwave MRT calculation. The default assumes average skin/clothing '
        'absorptivity and a human subject always has their back to the sun '
        'at a 45-degree angle (SHARP = 135).',
        default='--posture standing --sharp 135 --absorptivity 0.7 --emissivity 0.95',
        platform=['grasshopper']
    )
]



from pollination_dsl.alias import OutputAlias
from queenbee.io.common import IOAliasHandler


"""Alias for daylight factor recipe output."""
daylight_factor_results = [
    OutputAlias.any(
        name='results',
        description='Daylight factor values. These can be plugged into the "LB '
        'Spatial Heatmap" component along with meshes of the sensor grids to '
        'visualize results.',
        platform=['grasshopper'],
        handler=[
            IOAliasHandler(
                language='python',
                module='pollination_handlers.outputs.daylight',
                function='read_df_from_folder'
            )
        ]
    ),

    # Revit alias
    OutputAlias.any(
        name='results',
        description='Daylight factor values.',
        platform=['revit'],
        handler=[
            IOAliasHandler(
                language='csharp',
                module='Pollination.RevitHandlers',
                function='ReadDaylightFactorResultsFromFolder'
            ),

            IOAliasHandler(
                language='python',
                module='pollination_handlers.outputs.daylight',
                function='read_df_from_folder'
            )
        ]
    ),

    # Rhino alias
    OutputAlias.linked(
        name='results',
        platform=['rhino'],
        handler=[
            # Preload results 
            IOAliasHandler(
                language='python',
                module='pollination_handlers.outputs.daylight',
                function='read_df_from_folder'
            ),
            # load preloaded outputs to Rhino with following method
            IOAliasHandler(
                language='csharp', module='Pollination.RhinoHandlers',
                function='LoadMeshBasedResultsToRhino'
            )
        ]
    )
]


"""Alias for sky view recipe output."""
sky_view_results = [
    OutputAlias.any(
        name='results',
        description='Numbers for the sky view or sky exposure at each sensor. These '
        'can be plugged into the "LB Spatial Heatmap" component along with meshes of '
        'the sensor grids to visualize results. Values are in percent (between 0 '
        'and 100).',
        platform=['grasshopper'],
        handler=[
            IOAliasHandler(
                language='python',
                module='pollination_handlers.outputs.daylight',
                function='read_df_from_folder'
            )
        ]
    )
]


"""Point-in-time grid-based results."""
point_in_time_grid_results = [
    OutputAlias.any(
        name='results',
        description='Numbers for the point-in-time value at each sensor. These can be '
        'plugged into the "LB Spatial Heatmap" component along with meshes of the '
        'sensor grids to visualize results. Values are in the standard SI '
        'units of the requested input metric.\n* illuminance = lux'
        '\n* irradiance = W/m2\n* luminance = cd/m2\n* radiance = W/m2-sr',
        platform=['grasshopper'],
        handler=[
            IOAliasHandler(
                language='python',
                module='pollination_handlers.outputs.daylight',
                function='read_pit_from_folder'
            )
        ]
    )
]


"""Point-in-time view-based results."""
point_in_time_view_results = [
    OutputAlias.any(
        name='results',
        description='High Dynamic Range (HDR) images for each View in the model. These '
        'can be plugged into the Ladybug "Image Viewer" component to preview the image. '
        'They can also be plugged into the "HB False Color" component to convert '
        'the image into a false color version. Lastly, it can be connected to '
        'the "HB HDR to GIF" component to get a GIF image that is more portable '
        'and easily previewed by different software. Pixel values are '
        'in the standard SI units of the requested input metric.\n* illuminance = lux'
        '\n* irradiance = W/m2\n* luminance = cd/m2\n* radiance = W/m2-sr',
        platform=['grasshopper'],
        handler=[
            IOAliasHandler(
                language='python',
                module='pollination_handlers.outputs.daylight',
                function='read_images_from_folder'
            )
        ]
    )
]


"""Cumulative sun hours output from the direct sun hours recipe."""
cumulative_sun_hour_results = [
    OutputAlias.any(
        name='hours',
        description='The cumulative number of timesteps that each sensor sees the sun. '
        'If the input wea timestep is 1 (the default), then this is the number of '
        'direct sun hours for each sensor. These can be plugged into the "LB '
        'Spatial Heatmap" component along with meshes of the sensor grids to '
        'visualize results.',
        platform=['grasshopper'],
        handler=[
            IOAliasHandler(
                language='python',
                module='pollination_handlers.outputs.daylight',
                function='read_hours_from_folder'
            )
        ]
    )
]


"""Direct sun hours recipe output."""
direct_sun_hours_results = [
    OutputAlias.any(
        name='results',
        description='Raw result files (.ill) that contain the number of timesteps '
        'that each sensor is exposed to sun. The units are the timestep of '
        'input wea file. For an hourly wea, each value corresponds to an hour '
        'of direct sun.',
        platform=['grasshopper'],
        handler=[
            IOAliasHandler(
                language='python',
                module='pollination_handlers.outputs.daylight',
                function='sort_ill_from_folder'
            )
        ]
    )
]


"""Annual daylight recipe output."""
annual_daylight_results = [
    OutputAlias.any(
        name='results',
        description='Raw result files (.ill) that contain illuminance matrices.',
        platform=['grasshopper'],
        handler=[
            IOAliasHandler(
                language='python',
                module='pollination_handlers.outputs.daylight',
                function='sort_ill_from_folder'
            )
        ]
    )
]


daylight_autonomy_results = [
    OutputAlias.any(
        name='DA',
        description='Daylight autonomy values for each sensor. These can be plugged '
        'into the "LB Spatial Heatmap" component along with meshes of the sensor '
        'grids to visualize results.',
        platform=['grasshopper'],
        handler=[
            IOAliasHandler(
                language='python',
                module='pollination_handlers.outputs.daylight',
                function='read_da_from_folder'
            )
        ]
    ),
    # Rhino alias
    OutputAlias.linked(
        name='DA Results',
        platform=['rhino'],
        handler=[
            # Preload results 
            IOAliasHandler(
                language='python',
                module='pollination_handlers.outputs.daylight',
                function='read_da_from_folder'
            ),
            # load preloaded outputs to Rhino with following method
            IOAliasHandler(
                language='csharp', module='Pollination.RhinoHandlers',
                function='LoadMeshBasedResultsToRhino'
            )
        ]
    )
]


continuous_daylight_autonomy_results = [
    OutputAlias.any(
        name='cDA',
        description='Continuous daylight autonomy values for each sensor. These can '
        'be plugged into the "LB Spatial Heatmap" component along with meshes of '
        'the sensor grids to visualize results.',
        platform=['grasshopper'],
        handler=[
            IOAliasHandler(
                language='python',
                module='pollination_handlers.outputs.daylight',
                function='read_cda_from_folder'
            )
        ]
    ),
    # Rhino alias
    OutputAlias.linked(
        name='cDA Results',
        platform=['rhino'],
        handler=[
            # Preload results 
            IOAliasHandler(
                language='python',
                module='pollination_handlers.outputs.daylight',
                function='read_cda_from_folder'
            ),
            # load preloaded outputs to Rhino with following method
            IOAliasHandler(
                language='csharp', module='Pollination.RhinoHandlers',
                function='LoadMeshBasedResultsToRhino'
            )
        ]
    )
]


udi_results = [
    OutputAlias.any(
        name='UDI',
        description='Useful daylight autonomy values for each sensor. These can be '
        'plugged into the "LB Spatial Heatmap" component along with meshes of the '
        'sensor grids to visualize results.',
        platform=['grasshopper'],
        handler=[
            IOAliasHandler(
                language='python',
                module='pollination_handlers.outputs.daylight',
                function='read_udi_from_folder'
            )
        ]
    ),
    # Rhino alias
    OutputAlias.linked(
        name='UDI Results',
        platform=['rhino'],
        handler=[
            # Preload results 
            IOAliasHandler(
                language='python',
                module='pollination_handlers.outputs.daylight',
                function='read_udi_from_folder'
            ),
            # load preloaded outputs to Rhino with following method
            IOAliasHandler(
                language='csharp', module='Pollination.RhinoHandlers',
                function='LoadMeshBasedResultsToRhino'
            )
        ]
    )
]


udi_lower_results = [
    OutputAlias.any(
        name='UDI_low',
        description='Values for the percent of time that is below the lower threshold '
        'of useful daylight illuminance. These can be plugged into the "LB '
        'Spatial Heatmap" component along with meshes of the sensor grids to '
        'visualize results.',
        platform=['grasshopper'],
        handler=[
            IOAliasHandler(
                language='python',
                module='pollination_handlers.outputs.daylight',
                function='read_udi_from_folder'
            )
        ]
    ),
    # Rhino alias
    OutputAlias.linked(
        name='UDI low Results',
        platform=['rhino'],
        handler=[
            # Preload results 
            IOAliasHandler(
                language='python',
                module='pollination_handlers.outputs.daylight',
                function='read_udi_from_folder'
            ),
            # load preloaded outputs to Rhino with following method
            IOAliasHandler(
                language='csharp', module='Pollination.RhinoHandlers',
                function='LoadMeshBasedResultsToRhino'
            )
        ]
    )
]


udi_upper_results = [
    OutputAlias.any(
        name='UDI_up',
        description='Values for the percent of time that is above the upper threshold '
        'of useful daylight illuminance. These can be plugged into the "LB '
        'Spatial Heatmap" component along with meshes of the sensor grids to '
        'visualize results.',
        platform=['grasshopper'],
        handler=[
            IOAliasHandler(
                language='python',
                module='pollination_handlers.outputs.daylight',
                function='read_udi_from_folder'
            )
        ]
    ),
    # Rhino alias
    OutputAlias.linked(
        name='UDI up Results',
        platform=['rhino'],
        handler=[
            # Preload results 
            IOAliasHandler(
                language='python',
                module='pollination_handlers.outputs.daylight',
                function='read_udi_from_folder'
            ),
            # load preloaded outputs to Rhino with following method
            IOAliasHandler(
                language='csharp', module='Pollination.RhinoHandlers',
                function='LoadMeshBasedResultsToRhino'
            )
        ]
    )
]


"""Total Irradiance results from the Annual Irradiance recipe."""
total_radiation_results = [
    OutputAlias.any(
        name='results',
        description='Raw result files (.ill) that contain irradiance matrices '
        'for the total radiation at each sensor and timestep.',
        platform=['grasshopper'],
        handler=[
            IOAliasHandler(
                language='python',
                module='pollination_handlers.outputs.daylight',
                function='sort_ill_from_folder'
            )
        ]
    )
]


"""Direct Irradiance results from the Annual Irradiance recipe."""
direct_radiation_results = [
    OutputAlias.any(
        name='direct',
        description='Raw result files (.ill) that contain irradiance matrices '
        'for the direct radiation at each sensor and timestep.',
        platform=['grasshopper'],
        handler=[
            IOAliasHandler(
                language='python',
                module='pollination_handlers.outputs.daylight',
                function='sort_ill_from_folder'
            )
        ]
    )
]


"""Average Irradiance from the Annual Irradiance recipe."""
average_irradiance_results = [
    OutputAlias.any(
        name='avg_irr',
        description='The average irradiance in W/m2 for each sensor over the Wea '
        'time period.',
        platform=['grasshopper'],
        handler=[
            IOAliasHandler(
                language='python',
                module='pollination_handlers.outputs.daylight',
                function='read_pit_from_folder'
            )
        ]
    )
]


"""Peak Irradiance from the Annual Irradiance recipe."""
peak_irradiance_results = [
    OutputAlias.any(
        name='peak_irr',
        description='The highest irradiance value in W/m2 during the Wea time period. '
        'This is suitable for assessing the worst-case solar load of clear skies on '
        'cooling design days. It can also be used to determine the highest radiant '
        'temperatures that occupants might experience in over the time period of '
        'the Wea.',
        platform=['grasshopper'],
        handler=[
            IOAliasHandler(
                language='python',
                module='pollination_handlers.outputs.daylight',
                function='read_pit_from_folder'
            )
        ]
    )
]


"""Peak Irradiance from the Annual Irradiance recipe."""
cumulative_radiation_results = [
    OutputAlias.any(
        name='radiation',
        description='The cumulative radiation in kWh/m2 over the Wea time period.',
        platform=['grasshopper'],
        handler=[
            IOAliasHandler(
                language='python',
                module='pollination_handlers.outputs.daylight',
                function='read_pit_from_folder'
            )
        ]
    )
]


"""LEED Daylight Illuminance 9AM recipe output."""
illuminance_9am_results = [
    OutputAlias.any(
        name='ill_9am',
        description='Illuminance results for the 9AM simulation in lux.',
        platform=['grasshopper'],
        handler=[
            IOAliasHandler(
                language='python',
                module='pollination_handlers.outputs.daylight',
                function='read_pit_from_folder'
            )
        ]
    )
]


"""LEED Daylight Illuminance 3PM recipe output."""
illuminance_3pm_results = [
    OutputAlias.any(
        name='ill_3pm',
        description='Illuminance results for the 3PM simulation in lux.',
        platform=['grasshopper'],
        handler=[
            IOAliasHandler(
                language='python',
                module='pollination_handlers.outputs.daylight',
                function='read_pit_from_folder'
            )
        ]
    )
]


"""LEED Daylight Pass/Fail 9AM recipe output."""
pass_fail_9am_results = [
    OutputAlias.any(
        name='passing_9am',
        description='Pass/Fail results for the 9AM simulation as one/zero values.',
        platform=['grasshopper'],
        handler=[
            IOAliasHandler(
                language='python',
                module='pollination_handlers.outputs.daylight',
                function='read_pit_from_folder'
            )
        ]
    )
]

"""LEED Daylight Pass/Fail 9AM recipe output."""
pass_fail_3pm_results = [
    OutputAlias.any(
        name='passing_3pm',
        description='Pass/Fail results for the 3PM simulation as one/zero values.',
        platform=['grasshopper'],
        handler=[
            IOAliasHandler(
                language='python',
                module='pollination_handlers.outputs.daylight',
                function='read_pit_from_folder'
            )
        ]
    )
]


"""LEED Daylight Pass/Fail combined recipe output."""
pass_fail_comb_results = [
    OutputAlias.any(
        name='passing_comb',
        description='Pass/Fail results for the combined simulation as one/zero values.',
        platform=['grasshopper'],
        handler=[
            IOAliasHandler(
                language='python',
                module='pollination_handlers.outputs.daylight',
                function='read_pit_from_folder'
            )
        ]
    )
]


"""LEED daylight illuminance credit summary output.

The result is a JSON with a summary of the credits achieved.
"""
leed_ill_credit_summary_results = [
    OutputAlias.any(
        name='credits',
        description='The number of LEED daylight credits achieved and a summary of the '
        'percentage of the sensor grid area that meets the LEED daylight criteria.',
        platform=['grasshopper'],
        handler=[
            IOAliasHandler(
                language='python',
                module='pollination_handlers.outputs.daylight',
                function='ill_credit_json_from_path'
            )
        ]
    )
]



from pollination_dsl.alias import InputAlias
from queenbee.io.common import IOAliasHandler


"""Alias for yes/no inputs about whether to filter design days."""
filter_des_days_input = [
    InputAlias.any(
        name='filter_des_days',
        description='A boolean to note whether the ddy file should be filtered to only '
        'include 99.6 and 0.4 design days (True) or all design days in the ddy file '
        'should be used (False).',
        default=True,
        platform=['grasshopper'],
        handler=[
            IOAliasHandler(
                language='python',
                module='pollination_handlers.inputs.bool_options',
                function='filter_des_days_to_str'
            )
        ]
    )
]


"""Alias for yes/no inputs about whether to skip a view-based overture calculation."""
skip_overture_input = [
    InputAlias.any(
        name='skip_overture',
        description='A boolean to note whether an ambient file (.amb) should be '
        'generated for an overture calculation before the view is split into smaller '
        'views. With an overture calculation, the ambient file (aka ambient cache) is '
        'first populated with values. Thereby ensuring that - when reused to create '
        'an image - Radiance uses interpolation between already calculated values '
        'rather than less reliable extrapolation. The overture calculation has '
        'comparatively small computation time to full rendering but is single-core '
        'can become time consuming in situations with very high numbers of '
        'rendering multiprocessors.',
        default=False,
        platform=['grasshopper'],
        handler=[
            IOAliasHandler(
                language='python',
                module='pollination_handlers.inputs.bool_options',
                function='skip_overture_to_str'
            )
        ]
    )
]


"""Alias for yes/no inputs about whether glare control devices exist in a model."""
glare_control_devices_input = [
    InputAlias.any(
        name='glare_control',
        description='A boolean to note whether the model has "view-preserving automatic '
        '(with manual override) glare-control devices," which means that illuminance '
        'only needs to be above 300 lux and not between 300 and 3000 lux.',
        default=True,
        platform=['grasshopper'],
        handler=[
            IOAliasHandler(
                language='python',
                module='pollination_handlers.inputs.bool_options',
                function='glare_control_devices_to_str'
            )
        ]
    )
]


"""Alias for yes/no inputs about whether to use multipliers."""
use_multiplier_input = [
    InputAlias.any(
        name='use_multiplier',
        description='If True, the multipliers on each Building Stories will be '
        'passed along to the generated Honeybee Room objects, indicating the '
        'simulation will be run once for each unique room and then results '
        'will be multiplied. If False, full geometry objects will be written '
        'for each and every story in the building such that all resulting '
        'multipliers will be 1. (Default: False).',
        default=False,
        platform=['grasshopper'],
        handler=[
            IOAliasHandler(
                language='python',
                module='pollination_handlers.inputs.bool_options',
                function='use_multiplier_to_str'
            )
        ]
    )
]


"""Alias for yes/no inputs about whether a building is residential."""
is_residential_input = [
    InputAlias.any(
        name='is_residential',
        description='A boolean to note whether the model represents a residential '
        'or nonresidential building.',
        default=False,
        platform=['grasshopper'],
        handler=[
            IOAliasHandler(
                language='python',
                module='pollination_handlers.inputs.bool_options',
                function='is_residential_to_str'
            )
        ]
    )
]


"""Alias for yes/no inputs about whether a comfort map should be for SET."""
write_set_map_input = [
    InputAlias.any(
        name='write_set_map',
        description='A boolean to note whether the output temperature CSV should '
        'record Operative Temperature or Standard Effective Temperature (SET). '
        'SET is relatively intense to compute and so only recording Operative '
        'Temperature can greatly reduce run time, particularly when air speeds '
        'are low. However, SET accounts for all 6 PMV model inputs and so is a '
        'more representative "feels-like" temperature for the PMV model.',
        default=False,
        platform=['grasshopper'],
        handler=[
            IOAliasHandler(
                language='python',
                module='pollination_handlers.inputs.bool_options',
                function='write_set_map_to_str'
            )
        ]
    )
]


"""Alias for yes/no inputs about whether to compute sky view or sky exposure."""
sky_exposure_input = [
    InputAlias.any(
        name='exposure',
        description='A boolean to note whether the output values should be sky view '
        '(False) or sky exposure (True). Sky View is defined as the percent of the '
        'sky dome seen by a surface and Sky Exposure is the fraction of the sky '
        'dome seen by a point. (Default: False)',
        default=False,
        platform=['grasshopper'],
        handler=[
            IOAliasHandler(
                language='python',
                module='pollination_handlers.inputs.bool_options',
                function='sky_view_metric_to_str'
            )
        ]
    )
]


"""Alias for yes/no inputs about whether to use a cloudy or uniform sky."""
cloudy_uniform_input = [
    InputAlias.any(
        name='cloudy_sky',
        description='A boolean to note whether a uniform sky should be used  '
        '(False) or a cloudy overcast sky (True). (Default: False).',
        default=False,
        platform=['grasshopper'],
        handler=[
            IOAliasHandler(
                language='python',
                module='pollination_handlers.inputs.bool_options',
                function='cloudy_bool_to_str'
            )
        ]
    )
]



from pollination_dsl.alias import InputAlias
from queenbee.io.common import IOAliasHandler


"""Alias for inputs that expect a .ddy file as the recipe input."""
ddy_input = [
    InputAlias.any(
        name='ddy',
        description='The path to a .ddy file or an .epw file with design days to be '
        'used for the initial sizing calculation.',
        platform=['grasshopper'],
        handler=[
            IOAliasHandler(
                language='python',
                module='pollination_handlers.inputs.ddy',
                function='ddy_handler'
            )
        ]
    )
]



from pollination_dsl.alias import InputAlias
from queenbee.io.common import IOAliasHandler


"""Alias for simulation run periods."""
run_period_input = [
    InputAlias.str(
        name='run_period',
        description='An AnalysisPeriod to set the start and end dates of the '
        'simulation. If None, the simulation will be annual.',
        default='',
        platform=['grasshopper'],
        handler=[
            IOAliasHandler(
                language='python',
                module='pollination_handlers.inputs.runperiod',
                function='run_period_to_str'
            )
        ]
    )
]



from pollination_dsl.alias import InputAlias


"""Alias for annual daylight/radiation radiance parameters."""
rad_par_annual_input = [
    InputAlias.str(
        name='radiance_par',
        description='Text for the radiance parameters to be used for ray tracing. '
        '(Default: -ab 2 -ad 5000 -lw 2e-05).',
        default='-ab 2 -ad 5000 -lw 2e-05',
        platform=['grasshopper']
    )
]


"""Alias for rtrace (daylight factor + PIT) radiance parameters."""
rad_par_daylight_factor_input = [
    InputAlias.str(
        name='radiance_par',
        description='Text for the radiance parameters to be used for ray tracing. '
        '(Default: -ab 2 -aa 0.1 -ad 2048 -ar 64).',
        default='-ab 2 -aa 0.1 -ad 2048 -ar 64',
        platform=['grasshopper']
    )
]


"""Alias for sky view rtrace radiance parameters."""
rad_par_sky_view_input = [
    InputAlias.str(
        name='radiance_par',
        description='Text for the radiance parameters to be used for ray tracing. '
        '(Default: -aa 0.1 -ad 2048 -ar 64).',
        default='-aa 0.1 -ad 2048 -ar 64',
        platform=['grasshopper']
    )
]


"""Alias for rpict (view-based) radiance parameters."""
rad_par_view_input = [
    InputAlias.str(
        name='radiance_par',
        description='Text for the radiance parameters to be used for ray tracing. '
        '(Default: -ab 2 -aa 0.1 -ad 2048 -ar 64).',
        default='-ab 2 -aa 0.1 -ad 2048 -ar 64',
        platform=['grasshopper']
    )
]


"""Alias for LEED daylight credit rtrace radiance parameters."""
rad_par_leed_illuminance_input = [
    InputAlias.str(
        name='radiance_par',
        description='Text for the radiance parameters to be used for ray tracing. '
        '(Default: -ab 5 -aa 0.1 -ad 2048 -ar 64).',
        default='-ab 5 -aa 0.1 -ad 2048 -ar 64',
        platform=['grasshopper']
    )
]


"""Alias for thresholds of annual daylight."""
daylight_thresholds_input = [
    InputAlias.str(
        name='thresholds',
        description='A string to change the threshold for daylight autonomy (DA) and '
        'useful daylight illuminance (UDI). Valid keys are -t for daylight autonomy '
        'threshold, -lt for the lower threshold for useful daylight illuminance and '
        '-ut for the upper threshold. The order of the keys is not important '
        'and you can include one or all of them. For instance if you only want '
        'to change the upper threshold to 2000 lux you should use -ut 2000 '
        'as the input. (Default: -t 300 -lt 100 -ut 3000).',
        default='-t 300 -lt 100 -ut 3000',
        platform=['grasshopper']
    )
]



from pollination_dsl.alias import InputAlias
from queenbee.io.common import IOAliasHandler


"""Alias for inputs that expect an annual schedule as a .csv file."""
schedule_csv_input = [
    InputAlias.any(
        name='schedule',
        description='An annual occupancy schedule, either as a path to a csv file (with '
        '8760 rows), a Ladybug Hourly Continuous Data Collection or a HB-Energy '
        'schedule object. This can also be the identifier of a schedule in '
        'your HB-Energy schedule library. Any value in this schedule that is '
        '0.1 or above will be considered occupied.',
        optional=True,
        platform=['grasshopper'],
        handler=[
            IOAliasHandler(
                language='python',
                module='pollination_handlers.inputs.schedule',
                function='schedule_to_csv'
            )
        ]
    )
]



from pollination_dsl.alias import InputAlias
from queenbee.io.common import IOAliasHandler


"""Alias for inputs that expect a simulation parameter .json file as the recipe input."""
energy_simulation_parameter_input = [
    InputAlias.any(
        name='sim_par',
        description='A SimulationParameter object that describes all of the setting for '
        'the energy simulation. If None, some default simulation parameters will '
        'automatically be used. This can also be the path to a SimulationParameter '
        'JSON file.',
        optional=True,
        platform=['grasshopper'],
        handler=[
            IOAliasHandler(
                language='python',
                module='pollination_handlers.inputs.simulation',
                function='energy_sim_par_to_json'
            )
        ]
    )
]


"""Alias for inputs that expect a measures input."""
measures_input = [
    InputAlias.list(
        name='measures',
        description='An optional list of measures to apply to the OpenStudio model '
        'upon export. Use the "HB Load Measure" component to load a measure into '
        'Grasshopper and assign input arguments. Measures can be downloaded from the '
        'NREL Building Components Library (BCL) at (https://bcl.nrel.gov/).',
        default=[],
        optional=True,
        platform=['grasshopper'],
        handler=[
            IOAliasHandler(
                language='python',
                module='pollination_handlers.inputs.simulation',
                function='measures_to_folder'
            )
        ]
    )
]


"""Alias for inputs that expect a IDF string input."""
idf_additional_strings_input = [
    InputAlias.list(
        name='add_str',
        description='THIS OPTION IS JUST FOR ADVANCED USERS OF ENERGYPLUS. '
        'An additional text string to be appended to the IDF before '
        'simulation. The input should include complete EnergyPlus objects as a '
        'single string following the IDF format. This input can be used to include '
        'EnergyPlus objects that are not currently supported by honeybee.',
        default=[],
        platform=['grasshopper'],
        handler=[
            IOAliasHandler(
                language='python',
                module='pollination_handlers.inputs.simulation',
                function='list_to_additional_strings'
            )
        ]
    )
]


"""Alias for inputs that expect visualization variables."""
viz_variables_input = [
    InputAlias.list(
        name='viz_vars',
        description='A list of text for EnergyPlus output variables to be visualized '
        'on the geometry in an output HTML report. If unspecified, no report is '
        'produced. For example, "Zone Air System Sensible Heating Rate".',
        default=[],
        platform=['grasshopper'],
        handler=[
            IOAliasHandler(
                language='python',
                module='pollination_handlers.inputs.simulation',
                function='viz_variables_to_string'
            )
        ]
    )
]



from pollination_dsl.alias import InputAlias
from queenbee.io.common import IOAliasHandler


"""Alias for north inputs that can accept both an angle or a north vector."""
north_input = [
    InputAlias.any(
        name='north',
        description='A number between -360 and 360 for the counterclockwise difference '
        'between the North and the positive Y-axis in degrees. This can '
        'also be Vector for the direction to North. (Default: 0).',
        default=0,
        platform=['grasshopper'],
        handler=[
            IOAliasHandler(
                language='python',
                module='pollination_handlers.inputs.north',
                function='north_vector_to_angle'
            )
        ]
    )
]



from pollination_dsl.alias import InputAlias
from queenbee.io.common import IOAliasHandler


"""Alias inputs that expect a HBJSON model file as the recipe input."""
hbjson_model_input = [
    # grasshopper Alias
    InputAlias.any(
        name='model',
        description='A Honeybee Model to simulate or the path to a HBJSON file '
        'of a Model. This can also be the path to a HBpkl file, though this is only '
        'recommended for cases where the model is extremely large.',
        platform=['grasshopper'],
        handler=[
            IOAliasHandler(
                language='python', module='pollination_handlers.inputs.model',
                function='model_to_json'
            ),
            IOAliasHandler(
                language='csharp', module='Pollination.RhinoHandlers',
                function='HBModelToJSON'
            )
        ]
    ),
    # Rhino alias
    InputAlias.linked(
        name='model',
        description='This input links the model to Rhino model.',
        platform=['rhino'],
        handler=[
            IOAliasHandler(
                language='csharp', module='Pollination.RhinoHandlers',
                function='RhinoHBModelToJSON'
            )
        ]
    )
]


"""Alias inputs that expect a HBJSON model with sensor grids."""
hbjson_model_grid_input = [
    # grasshopper Alias
    InputAlias.any(
        name='model',
        description='A Honeybee Model to simulate or the path to a HBJSON file '
        'of a Model. This can also be the path to a HBpkl file, though this is only '
        'recommended for cases where the model is extremely large. Note that this '
        'model should have sensor grids assigned to it.',
        platform=['grasshopper'],
        handler=[
            IOAliasHandler(
                language='python', module='pollination_handlers.inputs.model',
                function='model_to_json_grid_check'
            ),
            IOAliasHandler(
                language='csharp', module='Pollination.RhinoHandlers',
                function='HBModelToJSON'
            )
        ]
    ),
    # Rhino alias
    InputAlias.linked(
        name='model',
        description='This input links the model to Rhino model.',
        platform=['rhino'],
        handler=[
            IOAliasHandler(
                language='csharp', module='Pollination.RhinoHandlers',
                function='RhinoHBModelToJSON'
            )
        ]
    )
]


"""Alias inputs that expect a HBJSON model with sensor grids and rooms."""
hbjson_model_grid_room_input = [
    # grasshopper Alias
    InputAlias.any(
        name='model',
        description='A Honeybee Model to simulate or the path to a HBJSON file '
        'of a Model. Note that this model must contain rooms and have sensor '
        'grids assigned to it.',
        platform=['grasshopper'],
        handler=[
            IOAliasHandler(
                language='python', module='pollination_handlers.inputs.model',
                function='model_to_json_grid_room_check'
            ),
            IOAliasHandler(
                language='csharp', module='Pollination.RhinoHandlers',
                function='HBModelToJSON'
            )
        ]
    ),
    # Rhino alias
    InputAlias.linked(
        name='model',
        description='This input links the model to Rhino model.',
        platform=['rhino'],
        handler=[
            IOAliasHandler(
                language='csharp', module='Pollination.RhinoHandlers',
                function='RhinoHBModelToJSON'
            )
        ]
    )
]


"""Alias inputs that expect a HBJSON model with views."""
hbjson_model_view_input = [
    # grasshopper Alias
    InputAlias.any(
        name='model',
        description='A Honeybee Model to simulate or the path to a HBJSON file '
        'of a Model. This can also be the path to a HBpkl file, though this is only '
        'recommended for cases where the model is extremely large. Note that this '
        'model should have views assigned to it.',
        platform=['grasshopper'],
        handler=[
            IOAliasHandler(
                language='python', module='pollination_handlers.inputs.model',
                function='model_to_json_view_check'
            ),
            IOAliasHandler(
                language='csharp', module='Pollination.RhinoHandlers',
                function='HBModelToJSON'
            )
        ]
    ),
    # Rhino alias
    InputAlias.linked(
        name='model',
        description='This input links the model to Rhino model.',
        platform=['rhino'],
        handler=[
            IOAliasHandler(
                language='csharp', module='Pollination.RhinoHandlers',
                function='RhinoHBModelToJSON'
            )
        ]
    )
]


"""Alias inputs that expect a HBJSON model with views."""
hbjson_model_view_input = [
    # grasshopper Alias
    InputAlias.any(
        name='model',
        description='A Honeybee Model to simulate or the path to a HBJSON file '
        'of a Model. This can also be the path to a HBpkl file, though this is only '
        'recommended for cases where the model is extremely large. Note that this '
        'model should have views assigned to it.',
        platform=['grasshopper'],
        handler=[
            IOAliasHandler(
                language='python', module='pollination_handlers.inputs.model',
                function='model_to_json_view_check'
            ),
            IOAliasHandler(
                language='csharp', module='Pollination.RhinoHandlers',
                function='HBModelToJSON'
            )
        ]
    ),
    # Rhino alias
    InputAlias.linked(
        name='model',
        description='This input links the model to Rhino model.',
        platform=['rhino'],
        handler=[
            IOAliasHandler(
                language='csharp', module='Pollination.RhinoHandlers',
                function='RhinoHBModelToJSON'
            )
        ]
    )
]

"""Alias inputs that expect a DFJSON model file as the recipe input."""
dfjson_model_input = [
    # grasshopper Alias
    InputAlias.any(
        name='model',
        description='A Dragonfly Model object or the path to a DFJSON file.',
        platform=['grasshopper'],
        handler=[
            IOAliasHandler(
                language='python', module='pollination_handlers.inputs.model',
                function='model_dragonfly_to_json'
            )
        ]
    )
]



from pollination_dsl.alias import InputAlias
from queenbee.io.common import IOAliasHandler


"""Alias for the selection of point-in-time metrics."""
point_in_time_metric_input = [
    InputAlias.any(
        name='metric',
        description='Either an integer or the full name of a point-in-time metric to '
        'be computed by the recipe. (Default: illuminance). Choose from the following:'
        '\n* 0 = illuminance\n* 1 = irradiance\n* 2 = luminance\n* 3 = radiance',
        default='illuminance',
        platform=['grasshopper'],
        handler=[
            IOAliasHandler(
                language='python',
                module='pollination_handlers.inputs.pit',
                function='point_in_time_metric_to_str'
            )
        ]
    )
]


"""Alias for the selection of point-in-time metrics."""
point_in_time_view_metric_input = [
    InputAlias.any(
        name='metric',
        description='Either an integer or the full name of a point-in-time metric to '
        'be computed by the recipe. (Default: luminance). Choose from the following:'
        '\n* 0 = illuminance\n* 1 = irradiance\n* 2 = luminance\n* 3 = radiance',
        default='luminance',
        platform=['grasshopper'],
        handler=[
            IOAliasHandler(
                language='python',
                module='pollination_handlers.inputs.pit',
                function='point_in_time_metric_to_str'
            )
        ]
    )
]



from pollination_dsl.alias import InputAlias
from queenbee.io.common import IOAliasHandler


"""Alias for inputs that expect a .wea file as the recipe input."""
wea_input = [
    InputAlias.any(
        name='wea',
        description='A Wea object produced from the Wea components that are under '
        'the Light Sources tab. This can also be the path to a .wea or a .epw file.',
        platform=['grasshopper'],
        handler=[
            IOAliasHandler(
                language='python',
                module='pollination_handlers.inputs.wea',
                function='wea_handler'
            )
        ]
    )
]


"""Alias for inputs that expect a .wea file at a timestep of 1."""
wea_input_timestep_check = [
    InputAlias.any(
        name='wea',
        description='A Wea object produced from the Wea components that are under '
        'the Light Sources tab. This can also be the path to a .wea or a .epw file.',
        platform=['grasshopper'],
        handler=[
            IOAliasHandler(
                language='python',
                module='pollination_handlers.inputs.wea',
                function='wea_handler_timestep_check'
            )
        ]
    )
]
